==> zio-aws-iot1clickdevices_2.13-5.17.126.2-sources.jar: zio/aws/iot1clickdevices/model/GetDeviceMethodsRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetDeviceMethodsRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest = {
    import GetDeviceMethodsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
      .builder()
      .deviceId(__string.unwrap(deviceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.wrap(buildAwsValue())
}
object GetDeviceMethodsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest =
      zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ) extends zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly {
    override val deviceId: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.deviceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ): zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.203.2-sources.jar: zio/aws/iot1clickdevices/model/GetDeviceMethodsRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetDeviceMethodsRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest = {
    import GetDeviceMethodsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
      .builder()
      .deviceId(deviceId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.wrap(buildAwsValue())
}
object GetDeviceMethodsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest =
      zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ) extends zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly {
    override val deviceId: __string = impl.deviceId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.GetDeviceMethodsRequest
  ): zio.aws.iot1clickdevices.model.GetDeviceMethodsRequest.ReadOnly =
    new Wrapper(impl)
}
